Error

Struct Error 

pub struct Error<Kind, Context> { /* private fields */ }
An error that has a Kind and optional list of Context instances.

The Kind represents the original root cause of the error, whereas the Context type provides additional information.

Implementations

Source

impl<Kind, Context> Error<Kind, Context>

pub fn new<T: Into<Kind>>(kind: T) -> Error<Kind, Context>

Creates a new Error of the desired kind. The created error contains no additional context information.

pub fn context<T: Into<Context>>(self, ctx: T) -> Self

Adds context to the error.

Source

impl<K, T> Error<ErrorKind<K, T>, Context>

pub fn end_of_stream() -> ParseError<K, T>

Creates a new ParseError with the kind ErrorKind::EndOfStream.

pub fn unexpected(span: Span, got: T, expected: String) -> ParseError<K, T>

Creates a new ParseError with the kind ErrorKind::UnexpectedToken.

pub fn other(span: Span, kind: K) -> ParseError<K, T>

Creates a new ParseError from an parser of format specific error type. The returned parse error will have a kind of ErrorKind::Other, with the kind set to the provided value.

pub fn span(&self) -> Option<&Span>

Returns the location of the error relative to the start of the input stream if known.