pub struct Error<Kind, Context> { /* private fields */ }Expand description
An error that has a Kind and optional list of Context instances.
The Kind represents the original root cause of the error, whereas
the Context type provides additional information.
Implementations
Sourceimpl<K, T> Error<ErrorKind<K, T>, Context>
impl<K, T> Error<ErrorKind<K, T>, Context>
Sourcepub fn end_of_stream() -> ParseError<K, T>
pub fn end_of_stream() -> ParseError<K, T>
Creates a new ParseError with the kind ErrorKind::EndOfStream.
Sourcepub fn unexpected(span: Span, got: T, expected: String) -> ParseError<K, T>
pub fn unexpected(span: Span, got: T, expected: String) -> ParseError<K, T>
Creates a new ParseError with the kind ErrorKind::UnexpectedToken.
Sourcepub fn other(span: Span, kind: K) -> ParseError<K, T>
pub fn other(span: Span, kind: K) -> ParseError<K, T>
Creates a new ParseError from an parser of format specific error type. The returned parse error will have a kind of ErrorKind::Other, with the kind set to the provided value.